import numpy as np
from matplotlib import pyplot as plt

datafile = 'data.tsv'

texp, cv = np.loadtxt(datafile).transpose()

B = 7.5E-3*1.1604E4 # rot const in kelvin

t = np.linspace(texp[0],texp[-1],100)

sigma = B/t

dsigma = .01

j_max = 5

def z0(sigma):
    j = np.arange(j_max+1)
    terms = (2.*j+1.)*np.exp(
        - np.outer(sigma,j*(j+1.))
    )
    return np.sum(
        terms,1
    )

def z1(sigma):
    j = np.arange(j_max+1)
    terms = (2.-(-1)**j)*(2.*j+1.)*np.exp(
        - np.outer(sigma,j*(j+1.))
    )
    return np.sum(
        terms,1
    )

def z2e(sigma):
    j = 2.*np.arange((j_max+1)/2)
    terms = 1.*(2.*j+1.)*np.exp(
        - np.outer(sigma,j*(j+1.))
    )
    return np.sum(
        terms,1
    )

def z2o(sigma):
    j = 2.*np.arange((j_max+1)/2) + 1.
    terms = 3.*(2.*j+1.)*np.exp(
        - np.outer(sigma,j*(j+1.))
    )
    return np.sum(
        terms,1
    )

def heatcap(z):
    return sigma**2 * (
        np.log(z(sigma+dsigma)) + np.log(z(sigma-dsigma)) - 2. * np.log(z(sigma))
    ) / dsigma**2

plt.plot(texp,cv,'.',label='exp')
plt.plot(t,heatcap(z0),label='$c_r$')
plt.plot(t,heatcap(z1),label='$c\'_r$')
sigmao = B/300.
rhoe = z2e(sigmao)
rhoo = z2o(sigmao)
Cv = (rhoe*heatcap(z2e)+rhoo*heatcap(z2o))/(rhoe+rhoo)
plt.plot(t,Cv,label='$c\'\'_r$')
plt.xlabel('temperature (K)')
plt.ylabel('molar heat capacity ($R$)')
plt.title('molar heat capacity vs. temperature')
plt.legend()
plt.show()


